<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="工位编码" prop="locationCode">
        <el-input
          v-model="queryParams.locationCode"
          placeholder="请输入工位编码"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="工位名称" prop="locationName">
        <el-input
          v-model="queryParams.locationName"
          placeholder="请输入工位名称"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="物料编码" prop="materialCode">
        <el-input
          v-model="queryParams.materialCode"
          placeholder="请输入物料编码"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="物料名称" prop="materialName">
        <el-input
          v-model="queryParams.materialName"
          placeholder="请输入物料名称"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="单位" prop="unit">
        <el-input
          v-model="queryParams.unit"
          placeholder="请输入单位"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item style="float: right">
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>
    <el-card style="margin-top: 10px" class="box-card">
    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['bs:bomChildInfo:add']"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['bs:bomChildInfo:edit']"
        >修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['bs:bomChildInfo:remove']"
        >删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          @click="handleExport"
          v-hasPermi="['bs:bomChildInfo:export']"
        >导出</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-close"
          size="mini"
          @click="handleClose"
        >关闭</el-button>
      </el-col>
    </el-row>

    <el-descriptions class="margin-top" :size="'medium'" border>
      <el-descriptions-item >
        <template slot="label">
          <i class="el-icon-user"></i>
          BOM编码
        </template>
          {{headerInformationData.bomCode}}
      </el-descriptions-item>
      <el-descriptions-item >
        <template slot="label">
          <i class="el-icon-location-outline"></i>
          产品编码
        </template>
        {{headerInformationData.productCode}}
      </el-descriptions-item>
      <el-descriptions-item >
        <template slot="label">
          <i class="el-icon-tickets"></i>
          产品名称
        </template>
        {{headerInformationData.productName}}
      </el-descriptions-item>
    </el-descriptions>

    <el-table border v-loading="loading" :data="bomChildInfoList" @selection-change="handleSelectionChange" v-if="bomChildInfoList.length > 0">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column show-overflow-tooltip="true" label="工位编码" align="center" prop="locationCode" />
      <el-table-column show-overflow-tooltip="true" label="工位名称" align="center" prop="locationName" />
      <el-table-column show-overflow-tooltip="true" label="物料编码" align="center" prop="materialCode" />
      <el-table-column show-overflow-tooltip="true" label="物料名称" align="center" prop="materialName" />
      <el-table-column show-overflow-tooltip="true" label="单耗" align="center" prop="costQty" />
      <el-table-column show-overflow-tooltip="true" label="单位" align="center" prop="unit" />
      <el-table-column show-overflow-tooltip="true" label="备注" align="center" prop="remark" />
    </el-table>
    <el-empty v-else>
      <span slot="description">暂无数据</span>
    </el-empty>
    </el-card>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改基础BOM子信息对话框 -->
    <el-dialog v-dialogpop-up :title="title" :visible.sync="open" width="500px" append-to-body>
        <span slot="title">
        <i class="el-icon-s-order"></i>
        {{titleName}}
      </span>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="BOM编码" prop="bomCode">
          <el-input v-model="querybomCode" :disabled="true" />
        </el-form-item>
        <el-form-item label="工位编码" prop="locationCode">
          <el-input v-model="form.locationCode" placeholder="请输入工位编码" />
        </el-form-item>
        <el-form-item label="工位名称" prop="locationName">
          <el-input v-model="form.locationName" placeholder="请输入工位名称" />
        </el-form-item>
        <el-form-item label="物料编码" prop="materialCode">
          <el-input v-model="form.materialCode" placeholder="请选择产品" >
            <el-button slot="append" @click="handleSelectMaterial" icon="el-icon-search"></el-button>
          </el-input>
          <ItemSelect ref="itemSelect" @onSelected="onItemSelected" > </ItemSelect>
        </el-form-item>
        <el-form-item label="物料名称" prop="materialName">
          <el-input disabled v-model="form.materialName" placeholder="请输入物料名称" />
        </el-form-item>
        <el-form-item label="单耗" prop="costQty">
          <el-input v-model="form.costQty" placeholder="请输入单耗" />
        </el-form-item>
        <el-form-item label="单位" prop="unit">
          <el-input v-model="form.unit" placeholder="请输入单位" />
        </el-form-item>
        <el-form-item label="备注" prop="remark">
          <el-input v-model="form.remark" placeholder="请输入备注" />
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listBomChildInfo, getBomChildInfo, delBomChildInfo, addBomChildInfo, updateBomChildInfo } from "@/api/main/bs/bomChildInfo";
import { listBomInfo } from "@/api/main/bs/bomInfo";
import ItemSelect from "@/components/itemSelect/single.vue";

export default {
  name: "BomChildInfo",
  components: {ItemSelect},
  data() {
    return {
      // 遮罩层
      loading: true,
      titleName: '',
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 基础BOM子信息表格数据
      bomChildInfoList: [],
      // 弹出层标题
      title: "",
      querybomCode: "",
      queryproductCode: "",
      queryproductName: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        productCode: null,
        productName: null,
        locationCode: null,
        locationName: null,
        materialCode: null,
        materialName: null,
        costQty: null,
        unit: null,
        bomCode: null,
      },
      headerInformationData:{
        bomCode: "",
        productCode: "",
        productName: ""
      },

      // 表单参数
      form: {},
      // 表单校验
      rules: {
        id: [
          { required: true, message: "主键id不能为空", trigger: "blur" }
        ],
      }
    };
  },
  created() {
    let bomCode = this.$route.query.bomCode;
    this.queryParams.bomCode = bomCode
    this.querybomCode = bomCode
    this.getList();
    this.headerInformation();
    this.getProcesses();
  },
  methods: {
    //物料选择弹出框
    onItemSelected(obj){
      if(obj !== undefined && obj !== null){
        this.form.materialCode = obj.materialCode;
        this.form.materialName = obj.materialName;
      }
    },
    handleSelectMaterial(){
      this.$refs.itemSelect.showFlag = true;
    },
    /** 返回按钮操作 */
    handleClose() {
      const obj = { path: "/main/bs/bomInfo" };
      this.$tab.closeOpenPage(obj);
    },
    /** BOM表头信息 */
    headerInformation() {
      listBomInfo(this.queryParams).then(response => {
        this.headerInformationData = response.rows[0];
      });
    },

    getProcesses() {
      listBomChildInfo(null).then(response => {
        this.options = response.rows;
      });
    },

    /** 查询基础BOM子信息列表 */
    getList() {
      this.loading = true;
      listBomChildInfo(this.queryParams).then(response => {
        this.bomChildInfoList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        productCode: null,
        productName: null,
        locationCode: null,
        locationName: null,
        materialCode: null,
        materialName: null,
        costQty: null,
        unit: null,
        remark: null,
        bomCode: null,
        delFlag: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加基础BOM子信息";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids
      getBomChildInfo(id).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改基础BOM子信息";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.form.bomCode = this.querybomCode;
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            updateBomChildInfo(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addBomChildInfo(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal.confirm('是否确认删除').then(function() {
        return delBomChildInfo(ids);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('bs/bomChildInfo/export', {
        ...this.queryParams
      }, `bomChildInfo_${new Date().getTime()}.xlsx`)
    }
  }
};
</script>
